<?php
/**
 * Anwiki is a multilingual content management system <http://www.anwiki.com>
 * Copyright (C) 2007-2008 Antoine Walter <http://www.anw.fr>
 * 
 * Anwiki is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3 of the License.
 * 
 * Anwiki is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Anwiki.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * List of untranslated contents.
 * @package Anwiki
 * @version $Id: action_untranslated.php,v 1.4 2008-09-11 22:40:39 antoine-cvs Exp $
 * @copyright 2007-2008 Antoine Walter
 * @license http://www.gnu.org/copyleft/gpl.html GNU Public License 3
 */

class AnwActionDefault_untranslated extends AnwActionGlobal implements AnwHarmlessAction
{
	function getNavEntry()
	{
		return $this->createNavEntry();
	}
	
	function run()
	{
		//initialize filters
		list($asAllLangs, $asDisplayLangs) = $this->filterLangs(array("translate"), true);
		list($asAllClasses, $asDisplayClasses) = $this->filterContentClasses();
		
		//get untranslated pages
		$aoPages = AnwStorage::getUntranslatedPages($asDisplayLangs, $asDisplayClasses);
		foreach ($aoPages as $i => $oPage)
		{
			if (!$oPage->isActionAllowed('view') 
				|| !$oPage->isActionAllowed('translate'))
			{
				unset($aoPages[$i]);
			}
		}
		
		if (AnwEnv::_GET("feed"))
		{
			$this->showFeed($aoPages);
		}
		else
		{
			$this->showHtml($aoPages, $asAllLangs, $asDisplayLangs, $asAllClasses, $asDisplayClasses);
		}
	}
	
	
	function showHtml($aoPages, $asAllLangs, $asDisplayLangs, $asAllClasses, $asDisplayClasses)
	{
		$this->out .= $this->tpl()->begin();
		
		$this->out .= $this->tpl()->filterStart()
					.$this->tpl()->filterLangs($asAllLangs, $asDisplayLangs)
					.$this->tpl()->filterClass($asAllClasses, $asDisplayClasses)
					.$this->tpl()->filterEnd();
		
		//rss link
		$sRssLink = AnwEnv::_SERVER('REQUEST_URI').'&feed=rss2';
		$this->head( $this->tpl()->headRss($sRssLink) );
		
		$this->out .= $this->tpl()->nav($sRssLink);
		
		//pages list
		$this->out .= $this->tpl()->openTable();
		foreach ($aoPages as $oPage)
		{
			$this->out .= $this->tpl()->untranslatedPageLine(
				$oPage
			);
		}
		$this->out .= $this->tpl()->closeTable();
	}
	
	
	function showFeed($aoPages)
	{
		$sFeedTitle = $this->t_("title")." - ".self::globalCfgWebsiteName();
		$oFeed = new AnwFeed( AnwEnv::_GET("feed"), $sFeedTitle, AnwUtils::aLink("untranslated") );
		
		foreach ($aoPages as $oPage)
		{
			//add to feed
			$sUserDisplayName = "";
			$sItemTitle = '['.$oPage->getLang().'] '.$oPage->getName().' ('.$oPage->getTranslatedPercent().'%) - '.Anwi18n::dateTime($oPage->getTime());
			$sPageLink = AnwUtils::link($oPage);
			
			$oFeedItem = new AnwFeedItem($sItemTitle, $sPageLink);
			$oFeedItem->setDate( $oPage->getTime() );
			$oFeedItem->setAuthor($sUserDisplayName);
			$oFeed->addItem($oFeedItem);
		}
		
		$oFeed->output();
	}
}

?>